ewa.transcode

Package ewa :: Module transcode |
[hide private]
[frames] | no frames]

# Module transcode

source code

Classes | [hide private]
| TranscodeError

Functions | [hide private]
lameTranscode(newBitRate, newSampleRate, newMode, masterPath, newPath, quiet=True) Executes LAME to transcode a file to a new bit rate, sample rate, and mode. | source code
transcode(masterPath, newPath, newBitRate, newSampleRate, newMode, allow_master=False, transcodeFunc=<function lameTranscode at 0x99c51b4>, **transcodeKwargs) transcodes master file at masterPath to specified bitrate, samplerate, and mode using transcodeFunc, by default one using LAME, to perform the transcoding. | source code

Variables | [hide private]
| __package__ = ``'``ewa``'``

Function Details | [hide private]

### transcode(masterPath, newPath, newBitRate, newSampleRate, newMode, allow_master=False, transcodeFunc=<function lameTranscode at 0x99c51b4>, **transcodeKwargs) | source code
transcodes master file at masterPath to specified bitrate, samplerate, and mode using transcodeFunc, by default one using LAME, to perform the transcoding. Returns either masterPath or newPath, depending on if the master path or new path should be used after possible transcoding.